==> crm-commom-vo-1.0.3.release.jar: com/biz/crm/nebular/sfa/notice/resp/SfaNoticeRespVo.java <==
package com.biz.crm.nebular.sfa.notice.resp;

import com.biz.crm.nebular.mdm.CrmExtVo;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumnRelation;
import com.bizunited.platform.saturn.engine.annotation.SaturnEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.util.List;

/**
 * 公告管理 返回vo
 *
 * @author liuhongming
 * @date 2020-09-17 17:14:42
 */
@Data
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@ApiModel(value = "公告管理 ")
@SaturnEntity(name = "SfaNoticeRespVo", description = "公告管理 ")
public class SfaNoticeRespVo extends CrmExtVo {

    @ApiModelProperty("公告编码 公告编码")
    @SaturnColumn(description = "公告编码 公告编码")
    private String noticeCode;

    @ApiModelProperty("公告标题 公告标题")
    @SaturnColumn(description = "公告标题 公告标题")
    private String noticeTitle;

    @ApiModelProperty("公告类型 公告类型")
    @SaturnColumn(description = "公告类型 公告类型")
    private String noticeType;

    @ApiModelProperty("有效开始时间 有效开始时间")
    @SaturnColumn(description = "有效开始时间 有效开始时间")
    private String beginDate;

    @ApiModelProperty("有效结束时间 有效结束时间")
    @SaturnColumn(description = "有效结束时间 有效结束时间")
    private String endDate;

    @ApiModelProperty("公告内容 公告内容")
    @SaturnColumn(description = "公告内容 公告内容")
    private String noticeContent;

    @ApiModelProperty("发布部门 发布部门")
    @SaturnColumn(description = "发布部门 发布部门")
    private String noticeOrg;

    @ApiModelProperty("发布时间 发布时间")
    @SaturnColumn(description = "发布时间 发布时间")
    private String noticeDate;

    @ApiModelProperty("访问次数 访问次数")
    @SaturnColumn(description = "访问次数 访问次数")
    private Integer visitNum;

    @ApiModelProperty("已读人数 已读人数")
    @SaturnColumn(description = "已读人数 已读人数")
    private Integer readUserNum;

    @ApiModelProperty("公告管理-公告发布范围")
    @SaturnColumn(description = "公告管理-公告发布范围")
    @SaturnColumnRelation(type = SaturnColumnRelation.RelationType.OneToMany)
    private List<SfaNoticeReceivingRespVo> noticeReceivingRespVos;

    @ApiModelProperty("公告管理-公告附件")
    @SaturnColumn(description = "公告管理-公告附件")
    @SaturnColumnRelation(type = SaturnColumnRelation.RelationType.OneToMany)
    private List<SfaNoticeFileRespVo> noticeFileRespVos;

}

==> crm-commom-vo-1.0.6.release.jar: com/biz/crm/nebular/sfa/notice/resp/SfaNoticeRespVo.java <==
package com.biz.crm.nebular.sfa.notice.resp;

import com.biz.crm.nebular.mdm.CrmExtVo;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumnRelation;
import com.bizunited.platform.saturn.engine.annotation.SaturnEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.util.List;

/**
 * 公告管理 返回vo
 *
 * @author liuhongming
 * @date 2020-09-17 17:14:42
 */
@Data
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@ApiModel(value = "公告管理 ")
@SaturnEntity(name = "SfaNoticeRespVo", description = "公告管理 ")
public class SfaNoticeRespVo extends CrmExtVo {

    @ApiModelProperty("公告编码 公告编码")
    @SaturnColumn(description = "公告编码 公告编码")
    private String noticeCode;

    @ApiModelProperty("公告标题 公告标题")
    @SaturnColumn(description = "公告标题 公告标题")
    private String noticeTitle;

    @ApiModelProperty("公告类型 公告类型")
    @SaturnColumn(description = "公告类型 公告类型")
    private String noticeType;

    @ApiModelProperty("公告类型描述 公告类型描述")
    @SaturnColumn(description = "公告类型描述 公告类型描述")
    private String noticeTypeDesc;

    @ApiModelProperty("有效开始时间 有效开始时间")
    @SaturnColumn(description = "有效开始时间 有效开始时间")
    private String beginDate;

    @ApiModelProperty("有效结束时间 有效结束时间")
    @SaturnColumn(description = "有效结束时间 有效结束时间")
    private String endDate;

    @ApiModelProperty("公告内容 公告内容")
    @SaturnColumn(description = "公告内容 公告内容")
    private String noticeContent;

    @ApiModelProperty("发布部门 发布部门")
    @SaturnColumn(description = "发布部门 发布部门")
    private String noticeOrg;

    @ApiModelProperty("发布时间 发布时间")
    @SaturnColumn(description = "发布时间 发布时间")
    private String noticeDate;

    @ApiModelProperty("访问次数 访问次数")
    @SaturnColumn(description = "访问次数 访问次数")
    private Integer visitNum;

    @ApiModelProperty("已读人数 已读人数")
    @SaturnColumn(description = "已读人数 已读人数")
    private Integer readUserNum;

    @ApiModelProperty("公告管理-公告发布范围")
    @SaturnColumn(description = "公告管理-公告发布范围")
    @SaturnColumnRelation(type = SaturnColumnRelation.RelationType.OneToMany)
    private List<SfaNoticeReceivingRespVo> noticeReceivingRespVos;

    @ApiModelProperty("公告管理-公告附件")
    @SaturnColumn(description = "公告管理-公告附件")
    @SaturnColumnRelation(type = SaturnColumnRelation.RelationType.OneToMany)
    private List<SfaNoticeFileRespVo> noticeFileRespVos;

}
